@@ -3,7 +3,7 @@ from ._class_recorder import (get_class, get_rpc_class, get_node_class, get_inte
                               list_class, Nodes, Rpcs, Devices, Managers, Parsers, Interfaces 
                               )
 from ._core_base import (kjoin, ksplit, reconfig, build_yaml, load_and_build, BaseData,
-                        open_object, _BaseObject)
+                        open_object, _BaseObject, path_walk_item , path_walk_attr, path)    
 from ._core_node import (BaseNode,
                          nodeproperty,  node, 
                           NodesReader, NodesWriter, 
@@ -16,11 +16,14 @@ from ._core_node_alias import (NodeAlias, NodeAlias1, nodealiasproperty, nodeali
 from ._extra_nodes import StaticNode, LocalNode
 
 from ._core_rpc import RpcError, BaseRpc, RpcProperty, rpcproperty, to_rpc_class
-from ._core_interface import buildproperty, BaseInterface, InterfaceProperty  
+from ._core_interface import BaseInterface, InterfaceProperty  
 
 from ._core_device import BaseDevice, DeviceProperty, open_device
 from ._core_manager import BaseManager, ManagerProperty, open_manager
 from ._core_com import BaseCom
 from ._core_model_var import NodeVar, NodeVar_R, NodeVar_W, NodeVar_RW, StaticVar
 
+from ._core_pydantic import Defaults, GenDevice, GenManager, GenInterface, GenNode
+
+
 from ._core_parser import *
