@@ -26,12 +26,14 @@ __all__ = [
 "AllTrue", 
 "AllFalse", 
 "AnyTrue", 
-"AnyFalse", 
+"AnyFalse",
+"NegNode", 
 "InsideIntervalNode", 
 "InsideCircleNode", 
 "PosNameNode", 
 "FormulaNode", 
-"FormulaNode1", 
+"FormulaNode1",
+"PolynomNode1",
 "StatisticNode", 
 "CounterNode", 
 "FormatNode", 
@@ -278,6 +280,13 @@ class AnyFalse(NodeAlias):
     def fget(*nodes):
         return not all(nodes)
 
+@record_class
+class NegNode(NodeAlias1):
+    """ Return the negative of the aliased node """
+    class Config(NodeAlias1.Config):
+        type = "NegNode"
+    def fget(self, value):
+        return not value 
 
 @record_class
 class CounterNode(BaseNode):
@@ -442,6 +451,28 @@ class FormulaNode1(NodeAlias1):
         return self._parser.evaluate({self._varname:value})
 
 
+@record_class
+class PolynomNode1(NodeAlias1):
+    """ Apply a polynome 
+
+    Config:
+        polynom (list) : list of coefficients (lowest first) 
+    """
+    class Config(NodeAlias1.Config):
+        polynom: List[float] = [0.0,1.0]
+        
+    
+    def fget(self, value):
+        if not self.config.polynom:
+            return 0.0
+        x = self.config.polynom[0]
+        for i,c in enumerate(self.config.polynom[1:], start=1):
+            x += c*value**i
+        return x
+
+PolynomNode = PolynomNode1 
+
+
 
 @record_class
 class StatisticNode(NodeAlias1):
